use itertools::Itertools;
use std::{ops::Deref, rc::Rc};
use yew::{function_component, html, AttrValue, Html, Properties, UseStateHandle};

use super::{close_modals, EditorViewState};

#[derive(Properties, PartialEq, Clone)]
pub(super) struct DeleteScriptProps {
    pub filename: AttrValue,
    pub editor_state: UseStateHandle<Rc<EditorViewState>>,
}

fn delete_script(filename: &AttrValue, state: &UseStateHandle<Rc<EditorViewState>>) {
    let mut new_state = (*state.deref().deref()).clone();

    if let Some((pos, _)) = new_state
        .available_files
        .iter()
        .find_position(|v| *v == filename)
    {
        new_state.available_files.remove(pos);
        if &new_state.open_file == filename {
            new_state.open_file = "init.lua".into();
        }
    }
    new_state.show_delete_dialog = None;
    state.set(new_state.into());
}

#[function_component(DeleteScriptDialog)]
pub(super) fn delete_script_dialog(props: &DeleteScriptProps) -> Html {
    let state_modalclose1 = props.editor_state.clone();
    let state_modalclose2 = props.editor_state.clone();
    let state_deletescript = props.editor_state.clone();
    let filename_deletescript = props.filename.clone();
    html! { <>
      <div class="modal-backdrop fade show"/>
        <div class="modal" tabindex="-1" aria-modal="true" role="dialog" style="display: block">
          <div class="modal-dialog">
            <div class="modal-content">
              <div class="modal-header">
                <h5 class="modal-title">{"Delete script"}</h5>
                  <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"
                     onclick={move |_ev| close_modals(&state_modalclose1) }></button>
              </div>
              <div class="modal-body">
                <p>{format!("Are you sure you wish to permanently delete {}?", props.filename)}</p>
              </div>
              <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-bs-dismiss="modal"
                        onclick={move |_ev| close_modals(&state_modalclose2) }>{"Close"}</button>
                <button type="button" class="btn btn-primary" onclick={move |_ev| delete_script(&filename_deletescript, &state_deletescript) }>{"Delete"}</button>
              </div>
            </div>
        </div>
      </div>
    </>}
}
